@@ -548,11 +548,9 @@ gjs_invoke_c_function(JSContext      *context,
             out_args_pos++;
         } else {
             GArgument *in_value;
-            GITypeTag type_tag;
             GITypeInfo ainfo;
 
             g_arg_info_load_type(&arg_info, &ainfo);
-            type_tag = g_type_info_get_tag(&ainfo);
 
             g_assert_cmpuint(in_args_pos, <, in_args_len);
             in_value = &in_arg_cvalues[in_args_pos];
@@ -844,7 +842,6 @@ function_call(JSContext *context,
     jsval *js_argv = JS_ARGV(context, vp);
     JSObject *object = JS_THIS_OBJECT(context, vp);
     JSObject *callee = JSVAL_TO_OBJECT(JS_CALLEE(context, vp));
-    jsval retval;
 #else
 static JSBool
 function_call(JSContext *context,
@@ -974,7 +971,7 @@ static struct JSClass gjs_function_class = {
     JS_PropertyStub,
     JS_PropertyStub,
     JS_PropertyStub,
-    JS_PropertyStub,
+    JS_StrictPropertyStub,
     JS_EnumerateStub,
     (JSResolveOp) function_new_resolve, /* needs cast since it's the new resolve signature */
     JS_ConvertStub,
@@ -999,7 +996,6 @@ init_cached_function_data (JSContext      *context,
                            GIFunctionInfo *info)
 {
     guint8 i, n_args;
-    gboolean is_method;
     GError *error = NULL;
     GITypeInfo return_type;
 
@@ -1008,8 +1004,6 @@ init_cached_function_data (JSContext      *context,
         return FALSE;
     }
 
-    is_method = (g_function_info_get_flags(info) & GI_FUNCTION_IS_METHOD) != 0;
-
     g_callable_info_load_return_type((GICallableInfo*)info, &return_type);
     if (g_type_info_get_tag(&return_type) != GI_TYPE_TAG_VOID)
       function->js_out_argc += 1;
